==> qtjambi-datavisualization-5.15.3-sources.jar: io/qt/datavis/QCustom3DLabel.java <==
package io.qt.datavis;


/**
 * <p>Adds a custom label to a graph</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html">QtDataVisualization::QCustom3DLabel</a></p>
 */
public class QCustom3DLabel extends io.qt.datavis.QCustom3DItem
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCustom3DLabel.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundColor-prop">QtDataVisualization::QCustom3DLabel::backgroundColorChanged(QColor)</a></p>
     */
    @io.qt.QtPropertyNotify(name="backgroundColor")
    public final Signal1<io.qt.gui.QColor> backgroundColorChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundEnabled-prop">QtDataVisualization::QCustom3DLabel::backgroundEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="backgroundEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> backgroundEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#borderEnabled-prop">QtDataVisualization::QCustom3DLabel::borderEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="borderEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> borderEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#facingCamera-prop">QtDataVisualization::QCustom3DLabel::facingCameraChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="facingCamera")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> facingCameraChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#font-prop">QtDataVisualization::QCustom3DLabel::fontChanged(QFont)</a></p>
     */
    @io.qt.QtPropertyNotify(name="font")
    public final Signal1<io.qt.gui.QFont> fontChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#text-prop">QtDataVisualization::QCustom3DLabel::textChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="text")
    public final Signal1<java.lang.String> textChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#textColor-prop">QtDataVisualization::QCustom3DLabel::textColorChanged(QColor)</a></p>
     */
    @io.qt.QtPropertyNotify(name="textColor")
    public final Signal1<io.qt.gui.QColor> textColorChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCustom3DLabel(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCustom3DLabel() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#QCustom3DLabel">QtDataVisualization::QCustom3DLabel::QCustom3DLabel(QObject*)</a></p>
     */
    public QCustom3DLabel(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCustom3DLabel instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QCustom3DLabel(java.lang.String, io.qt.gui.QFont, io.qt.gui.QVector3D, io.qt.gui.QVector3D, io.qt.gui.QQuaternion, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCustom3DLabel(java.lang.String text, io.qt.gui.QFont font, io.qt.gui.QVector3D position, io.qt.gui.QVector3D scaling, io.qt.gui.QQuaternion rotation) {
        this(text, font, position, scaling, rotation, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#QCustom3DLabel-1">QtDataVisualization::QCustom3DLabel::QCustom3DLabel(QString,QFont,QVector3D,QVector3D,QQuaternion,QObject*)</a></p>
     */
    public QCustom3DLabel(java.lang.String text, io.qt.gui.QFont font, io.qt.gui.QVector3D position, io.qt.gui.QVector3D scaling, io.qt.gui.QQuaternion rotation, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, text, font, position, scaling, rotation, parent);
    }
    
    private native static void initialize_native(QCustom3DLabel instance, java.lang.String text, io.qt.gui.QFont font, io.qt.gui.QVector3D position, io.qt.gui.QVector3D scaling, io.qt.gui.QQuaternion rotation, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundColor-prop">QtDataVisualization::QCustom3DLabel::backgroundColor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backgroundColor")
    @io.qt.QtUninvokable
    public final io.qt.gui.QColor backgroundColor(){
        return backgroundColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QColor backgroundColor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#font-prop">QtDataVisualization::QCustom3DLabel::font()const</a></p>
     */
    @io.qt.QtPropertyReader(name="font")
    @io.qt.QtUninvokable
    public final io.qt.gui.QFont font(){
        return font_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QFont font_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundEnabled-prop">QtDataVisualization::QCustom3DLabel::isBackgroundEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backgroundEnabled")
    @io.qt.QtUninvokable
    public final boolean isBackgroundEnabled(){
        return isBackgroundEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isBackgroundEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#borderEnabled-prop">QtDataVisualization::QCustom3DLabel::isBorderEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="borderEnabled")
    @io.qt.QtUninvokable
    public final boolean isBorderEnabled(){
        return isBorderEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isBorderEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#facingCamera-prop">QtDataVisualization::QCustom3DLabel::isFacingCamera()const</a></p>
     */
    @io.qt.QtPropertyReader(name="facingCamera")
    @io.qt.QtUninvokable
    public final boolean isFacingCamera(){
        return isFacingCamera_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isFacingCamera_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundColor-prop">QtDataVisualization::QCustom3DLabel::setBackgroundColor(QColor)</a></p>
     */
    @io.qt.QtPropertyWriter(name="backgroundColor")
    @io.qt.QtUninvokable
    public final void setBackgroundColor(io.qt.gui.QColor color){
        setBackgroundColor_native_cref_QColor(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(color));
    }
    
    @io.qt.QtUninvokable
    private native void setBackgroundColor_native_cref_QColor(long __this__nativeId, long color);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundEnabled-prop">QtDataVisualization::QCustom3DLabel::setBackgroundEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="backgroundEnabled")
    @io.qt.QtUninvokable
    public final void setBackgroundEnabled(boolean enabled){
        setBackgroundEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setBackgroundEnabled_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#borderEnabled-prop">QtDataVisualization::QCustom3DLabel::setBorderEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="borderEnabled")
    @io.qt.QtUninvokable
    public final void setBorderEnabled(boolean enabled){
        setBorderEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setBorderEnabled_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#facingCamera-prop">QtDataVisualization::QCustom3DLabel::setFacingCamera(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="facingCamera")
    @io.qt.QtUninvokable
    public final void setFacingCamera(boolean enabled){
        setFacingCamera_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setFacingCamera_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#font-prop">QtDataVisualization::QCustom3DLabel::setFont(QFont)</a></p>
     */
    @io.qt.QtPropertyWriter(name="font")
    @io.qt.QtUninvokable
    public final void setFont(io.qt.gui.QFont font){
        setFont_native_cref_QFont(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(font));
    }
    
    @io.qt.QtUninvokable
    private native void setFont_native_cref_QFont(long __this__nativeId, long font);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#text-prop">QtDataVisualization::QCustom3DLabel::setText(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="text")
    @io.qt.QtUninvokable
    public final void setText(java.lang.String text){
        setText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @io.qt.QtUninvokable
    private native void setText_native_cref_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#textColor-prop">QtDataVisualization::QCustom3DLabel::setTextColor(QColor)</a></p>
     */
    @io.qt.QtPropertyWriter(name="textColor")
    @io.qt.QtUninvokable
    public final void setTextColor(io.qt.gui.QColor color){
        setTextColor_native_cref_QColor(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(color));
    }
    
    @io.qt.QtUninvokable
    private native void setTextColor_native_cref_QColor(long __this__nativeId, long color);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#text-prop">QtDataVisualization::QCustom3DLabel::text()const</a></p>
     */
    @io.qt.QtPropertyReader(name="text")
    @io.qt.QtUninvokable
    public final java.lang.String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#textColor-prop">QtDataVisualization::QCustom3DLabel::textColor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="textColor")
    @io.qt.QtUninvokable
    public final io.qt.gui.QColor textColor(){
        return textColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QColor textColor_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCustom3DLabel(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCustom3DLabel(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCustom3DLabel instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-datavisualization-5.15.12-sources.jar: io/qt/datavis/QCustom3DLabel.java <==
package io.qt.datavis;


/**
 * <p>Adds a custom label to a graph</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html">QtDataVisualization::QCustom3DLabel</a></p>
 */
public class QCustom3DLabel extends io.qt.datavis.QCustom3DItem
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCustom3DLabel.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundColor-prop">QtDataVisualization::QCustom3DLabel::backgroundColorChanged(QColor)</a></p>
     */
    @io.qt.QtPropertyNotify(name="backgroundColor")
    public final Signal1<io.qt.gui.QColor> backgroundColorChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundEnabled-prop">QtDataVisualization::QCustom3DLabel::backgroundEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="backgroundEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> backgroundEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#borderEnabled-prop">QtDataVisualization::QCustom3DLabel::borderEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="borderEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> borderEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#facingCamera-prop">QtDataVisualization::QCustom3DLabel::facingCameraChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="facingCamera")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> facingCameraChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#font-prop">QtDataVisualization::QCustom3DLabel::fontChanged(QFont)</a></p>
     */
    @io.qt.QtPropertyNotify(name="font")
    public final Signal1<io.qt.gui.QFont> fontChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#text-prop">QtDataVisualization::QCustom3DLabel::textChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="text")
    public final Signal1<java.lang.String> textChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#textColor-prop">QtDataVisualization::QCustom3DLabel::textColorChanged(QColor)</a></p>
     */
    @io.qt.QtPropertyNotify(name="textColor")
    public final Signal1<io.qt.gui.QColor> textColorChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCustom3DLabel(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCustom3DLabel() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#QCustom3DLabel">QtDataVisualization::QCustom3DLabel::QCustom3DLabel(QObject*)</a></p>
     */
    public QCustom3DLabel(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCustom3DLabel instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QCustom3DLabel(java.lang.String, io.qt.gui.QFont, io.qt.gui.QVector3D, io.qt.gui.QVector3D, io.qt.gui.QQuaternion, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCustom3DLabel(java.lang.String text, io.qt.gui.QFont font, io.qt.gui.QVector3D position, io.qt.gui.QVector3D scaling, io.qt.gui.QQuaternion rotation) {
        this(text, font, position, scaling, rotation, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#QCustom3DLabel-1">QtDataVisualization::QCustom3DLabel::QCustom3DLabel(QString,QFont,QVector3D,QVector3D,QQuaternion,QObject*)</a></p>
     */
    public QCustom3DLabel(java.lang.String text, io.qt.gui.QFont font, io.qt.gui.QVector3D position, io.qt.gui.QVector3D scaling, io.qt.gui.QQuaternion rotation, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, text, font, position, scaling, rotation, parent);
    }
    
    private native static void initialize_native(QCustom3DLabel instance, java.lang.String text, io.qt.gui.QFont font, io.qt.gui.QVector3D position, io.qt.gui.QVector3D scaling, io.qt.gui.QQuaternion rotation, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundColor-prop">QtDataVisualization::QCustom3DLabel::backgroundColor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backgroundColor")
    @io.qt.QtUninvokable
    public final io.qt.gui.QColor backgroundColor(){
        return backgroundColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QColor backgroundColor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#font-prop">QtDataVisualization::QCustom3DLabel::font()const</a></p>
     */
    @io.qt.QtPropertyReader(name="font")
    @io.qt.QtUninvokable
    public final io.qt.gui.QFont font(){
        return font_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QFont font_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundEnabled-prop">QtDataVisualization::QCustom3DLabel::isBackgroundEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backgroundEnabled")
    @io.qt.QtUninvokable
    public final boolean isBackgroundEnabled(){
        return isBackgroundEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isBackgroundEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#borderEnabled-prop">QtDataVisualization::QCustom3DLabel::isBorderEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="borderEnabled")
    @io.qt.QtUninvokable
    public final boolean isBorderEnabled(){
        return isBorderEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isBorderEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#facingCamera-prop">QtDataVisualization::QCustom3DLabel::isFacingCamera()const</a></p>
     */
    @io.qt.QtPropertyReader(name="facingCamera")
    @io.qt.QtUninvokable
    public final boolean isFacingCamera(){
        return isFacingCamera_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isFacingCamera_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundColor-prop">QtDataVisualization::QCustom3DLabel::setBackgroundColor(QColor)</a></p>
     */
    @io.qt.QtPropertyWriter(name="backgroundColor")
    @io.qt.QtUninvokable
    public final void setBackgroundColor(io.qt.gui.QColor color){
        setBackgroundColor_native_cref_QColor(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(color));
    }
    
    @io.qt.QtUninvokable
    private native void setBackgroundColor_native_cref_QColor(long __this__nativeId, long color);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#backgroundEnabled-prop">QtDataVisualization::QCustom3DLabel::setBackgroundEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="backgroundEnabled")
    @io.qt.QtUninvokable
    public final void setBackgroundEnabled(boolean enabled){
        setBackgroundEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setBackgroundEnabled_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#borderEnabled-prop">QtDataVisualization::QCustom3DLabel::setBorderEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="borderEnabled")
    @io.qt.QtUninvokable
    public final void setBorderEnabled(boolean enabled){
        setBorderEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setBorderEnabled_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#facingCamera-prop">QtDataVisualization::QCustom3DLabel::setFacingCamera(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="facingCamera")
    @io.qt.QtUninvokable
    public final void setFacingCamera(boolean enabled){
        setFacingCamera_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setFacingCamera_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#font-prop">QtDataVisualization::QCustom3DLabel::setFont(QFont)</a></p>
     */
    @io.qt.QtPropertyWriter(name="font")
    @io.qt.QtUninvokable
    public final void setFont(io.qt.gui.QFont font){
        setFont_native_cref_QFont(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(font));
    }
    
    @io.qt.QtUninvokable
    private native void setFont_native_cref_QFont(long __this__nativeId, long font);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#text-prop">QtDataVisualization::QCustom3DLabel::setText(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="text")
    @io.qt.QtUninvokable
    public final void setText(java.lang.String text){
        setText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @io.qt.QtUninvokable
    private native void setText_native_cref_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#textColor-prop">QtDataVisualization::QCustom3DLabel::setTextColor(QColor)</a></p>
     */
    @io.qt.QtPropertyWriter(name="textColor")
    @io.qt.QtUninvokable
    public final void setTextColor(io.qt.gui.QColor color){
        setTextColor_native_cref_QColor(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(color));
    }
    
    @io.qt.QtUninvokable
    private native void setTextColor_native_cref_QColor(long __this__nativeId, long color);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#text-prop">QtDataVisualization::QCustom3DLabel::text()const</a></p>
     */
    @io.qt.QtPropertyReader(name="text")
    @io.qt.QtUninvokable
    public final java.lang.String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcustom3dlabel.html#textColor-prop">QtDataVisualization::QCustom3DLabel::textColor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="textColor")
    @io.qt.QtUninvokable
    public final io.qt.gui.QColor textColor(){
        return textColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QColor textColor_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCustom3DLabel(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCustom3DLabel(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCustom3DLabel instance, QDeclarativeConstructor constructor);
    
}
